<?php
/**
 * Lucks - Checkout API example
 * This page displays the user cart with the Lucks button
 */

// Include config
require_once "config.php";

// Include Lucks library
require_once "lucks-api.php";

// Prepare the html list of the items the user wants to buy and compute the final price
$itemsHtml = "";
$itemsTxt = "";
$total = 0;
foreach ($itemsForSale as $name => $price) {
    $preparedName = str_replace(" ", "_", $name); // PHP replace spaces by underscores in $_POST
    if (isset($_POST[$preparedName]) && $_POST[$preparedName] > 0) {
        $quantity = intval($_POST[$preparedName]);
        $linePrice = $price * $quantity;
        $itemsHtml .= htmlspecialchars($name)." (".htmlspecialchars($price)." Lucks) x $quantity = $linePrice<br />";
        $itemsTxt .= "$name x $quantity = $linePrice\n";
        $total += $linePrice;
    }
}

// Get a transaction ID for the computed price
$transactionId = lucksGetTransactionId(STORE_KEY, $total, SITE_URL."checkout-return.php", "Your purchase on MyShop");

// Check the transaction
if (strlen($transactionId) != 16) {
    print("An error occured while preparing transaction, please try again! Error code: $transactionId");
    exit;
}

// Save the transaction localy (here we use files but you better use a database)
file_put_contents("transactions/pending/$transactionId.txt", "$itemsTxt\nTotal: $total");

?><!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" />
        <title>MyShop - Your cart</title>
        <style>
            body { font-family: sans-serif; text-align: center; }
            h1 a { color: black; text-decoration: none; outline: none; }
            #content { width: 100%; max-width: 750px; display: inline-block; background-color: #f0f0f0; padding-bottom: 50px; }
            input[type=number] { width: 50px; }
            input[type=submit] { font-size: 15px; font-weight: bold; border: 1px solid black; border-radius: 3px; padding: 5px; cursor: pointer; }
        </style>
    </head>
    <body>
        <h1><a href="index.php">MyShop</a></h1>
        <div id="content">
            <h2>Your cart</h2>
            <a href="index.php">&lt; Back</a><br /><br />
            <?=$itemsHtml?><br /><br />
            <b>Total: <?=$total?> Lucks</b><br /><br /><br />

            <!-- Pay with Lucks button -->
            <div class="pay-with-lucks-button" data-transaction-key="<?=$transactionId?>" data-size="medium" data-pay-with="Pay with"></div>
            <script src="https://lucks.money/static/js/button.js"></script>

        </div>
    </body>
</html>