<?php
/**
 * Lucks - Checkout API example
 * This page is displayed after the user paid or reject the transaction
 */

// Include config
require_once "config.php";

// Include Lucks library
require_once "lucks-api.php";

// Check for the transaction ID
if (!isset($_POST['transaction']) || !ctype_alnum($_POST['transaction']) || strlen($_POST['transaction']) != 16) {
    print("Error: missing transaction id!");
    exit;
}

// Final status
$finalStatus = "pending"; // Pending by default

// Check if the transaction is still pending
if (file_exists("transactions/pending/".$_POST['transaction'].".txt")) {

    // Get the status
    $status = lucksGetTransactionStatus(STORE_KEY, $_POST['transaction']);

    // If still pending we display an error
    if ($status == "pending") {
        print("Error: transaction is still pending!");
        exit;
    }

    // else we move to the correct status
    else if ($status == "paid" || $status == "rejected" || $status == "not-found") {
        $status = $status == "not-found" ? "rejected": $status; // If not found we put in rejected
        rename("transactions/pending/".$_POST['transaction'].".txt", "transactions/$status/".$_POST['transaction'].".txt");
        $finalStatus = $status;
    }

    // Else we print an error
    else {
        print("Error: Lucks API error");
        exit;
    }
}

// Check if the transaction has been paid and double-check
else if (file_exists("transactions/paid/".$_POST['transaction'].".txt")) {
    $status = lucksGetTransactionStatus(STORE_KEY, $_POST['transaction']);
    if ($status == "paid") {
        $finalStatus = "paid";
    } else if ($status != "error") {
        // If status is not paid and not error, we move it to rejected
        rename("transactions/pending/".$_POST['transaction'].".txt", "transactions/rejected/".$_POST['transaction'].".txt");
        $finalStatus = "rejected";
    }
}

// Check if the transaction has been rejected
else if (file_exists("transactions/rejected/".$_POST['transaction'].".txt")) {
    $finalStatus = "rejected";
}

// Prepare the html code based on the final status
$messageHtml = "";
if ($finalStatus == "paid") {
    $messageHtml = "<h2>Your purchase has been registered</h2><br /><br /><b>Informations:</b><br /><br />".nl2br(htmlspecialchars(file_get_contents("transactions/paid/".$_POST['transaction'].".txt")));
} else if ($finalStatus == "rejected") {
    $messageHtml = "<h2>Your purchase has been rejected, please try again</h2>";
}

?><!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" />
        <title>MyShop - Your cart</title>
        <style>
            body { font-family: sans-serif; text-align: center; }
            h1 a { color: black; text-decoration: none; outline: none; }
            #content { width: 100%; max-width: 750px; display: inline-block; background-color: #f0f0f0; padding-bottom: 50px; }
            input[type=number] { width: 50px; }
            input[type=submit] { font-size: 15px; font-weight: bold; border: 1px solid black; border-radius: 3px; padding: 5px; cursor: pointer; }
        </style>
    </head>
    <body>
        <h1><a href="index.php">MyShop</a></h1>
        <div id="content">
            <?=$messageHtml?>
        </div>
    </body>
</html>